DidomiInitializeParameters class
Initialization parameters for Didomi SDK
Constructors
- DidomiInitializeParameters({required String apiKey, String? localConfigurationPath, String? remoteConfigurationUrl, String? providerId, bool disableDidomiRemoteConfig = false, String? languageCode, String? noticeId, String? androidTvNoticeId, bool androidTvEnabled = false, String? countryCode, String? regionCode, bool isUnderage = false})
Properties
- androidTvEnabled ↔ bool
-
If set to true, when launched on a AndroidTV device, the SDK will display TV notice:
getter/setter pair
- androidTvNoticeId ↔ String?
-
ID of the notice configuration to load on TV devices if you are not using app ID targeting.
If androidTvEnabled is true and SDK is launched on a TV device, this parameter will be used instead of noticeId to get configuration from console.
getter/setter pair
- apiKey ↔ String
-
Your API key.
getter/setter pair
- countryCode ↔ String?
-
Override user country code when determining the privacy regulation to apply.
Keep null to let the Didomi SDK determine the user country.
getter/setter pair
- disableDidomiRemoteConfig ↔ bool
-
If set to true, disable remote configuration (only local config file will be used).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isUnderage ↔ bool
-
If set to true, the SDK will only display the underage notice (false by default).
getter/setter pair
- languageCode ↔ String?
-
Language in which the consent UI should be displayed.
By default, the consent UI is displayed in the language configured in the device settings, if language is available and enabled by your configuration.
This property allows you to override the default setting and specify a language to display the UI in.
String containing the language code e.g.: "es", "fr", etc.
getter/setter pair
- localConfigurationPath ↔ String?
-
Path to client specific config file in the app assets in JSON format (
didomi_config.jsonby default).getter/setter pair - noticeId ↔ String?
-
ID of the notice configuration to load if you are not using app ID targeting (mobile devices).
getter/setter pair
- providerId ↔ String?
-
Your provider ID (if any).
getter/setter pair
- regionCode ↔ String?
-
Override user region code when determining the privacy regulation to apply.
Keep null to let the Didomi SDK determine the user region.
Ignored if countryCode is not set.
getter/setter pair
- remoteConfigurationUrl ↔ String?
-
URL to client specific remote config file in JSON format.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited